@@ -3,6 +3,7 @@ from __future__ import annotations
 import functools
 import re
 import sys
+import time as time_
 from datetime import datetime as datetime_
 from datetime import timezone as timezone_
 from decimal import Decimal
@@ -76,14 +77,16 @@ def _transform_value(value: Union[str_, datetime_, object, int, float, Decimal,
         ):
             str_value = datetime_.utcfromtimestamp(float(str_value)).isoformat(timespec="microseconds") + "Z"
     except Exception:
-        raise ValueError(f"Input value '{value}' (type: {value.__class__}) does not match allowed input format")
+        raise ValueError(f"The input value '{value}' (type: {value.__class__}) does not match allowed input formats")
 
     if PREFERRED_FORMAT_REGEX.match(str_value):
         if int(str_value[8:10]) >= 30 or (int(str_value[5:7]) == 2 and int(str_value[8:10]) >= 28):
             try:
                 dt_value = datetime_.strptime(str_value[0:10], "%Y-%m-%d")
             except ValueError:
-                raise ValueError(f"Input value '{value}' (type: {value.__class__}) does not match allowed input format")
+                raise ValueError(
+                    f"The input value '{value}' (type: {value.__class__}) does not match allowed input formats"
+                )
         return (str_value[:10] + "T" + str_value[11:]).upper().rstrip("Z").rsplit("+00:00")[0].rsplit("-00:00")[0] + "Z"
 
     ends_with_utc = False
@@ -99,12 +102,12 @@ def _transform_value(value: Union[str_, datetime_, object, int, float, Decimal,
 
         if ends_with_utc and dt_value.tzinfo:
             raise ValueError(
-                f"Input value '{value}' (type: {value.__class__}) uses double timezone declaration: 'UTC' and '{dt_value.tzinfo}'"
+                f"The input value '{value}' (type: {value.__class__}) uses double timezone declaration: 'UTC' and '{dt_value.tzinfo}'"
             )
 
         break
     else:
-        raise ValueError(f"Input value '{value}' (type: {value.__class__}) does not match allowed input format")
+        raise ValueError(f"The input value '{value}' (type: {value.__class__}) does not match allowed input formats")
 
     if not dt_value.tzinfo:
         # Timezone declaration missing, skipping tz application and blindly assuming UTC
@@ -115,9 +118,15 @@ def _transform_value(value: Union[str_, datetime_, object, int, float, Decimal,
 
 @functools.lru_cache(maxsize=128)
 def _timestamp_to_datetime(value: str_) -> datetime_:
+    value = _transform_value(value)
     return datetime_.strptime(value, "%Y-%m-%dT%H:%M:%S.%f%z")
 
 
+@functools.lru_cache(maxsize=128)
+def _timestamp_to_unixtime(value: str_) -> float:
+    return _timestamp_to_datetime(value).timestamp()
+
+
 class _metaclass(type):
     def __new__(cls: Type[_metaclass], name: str_, bases: Tuple[type, ...], attributedict: Dict) -> _metaclass:
         result = cast(Type["_baseclass"], super().__new__(cls, name, bases, dict(attributedict)))
@@ -135,7 +144,22 @@ class _baseclass(metaclass=_metaclass):
         return _transform_value(value)
 
 
+class now_(_baseclass):
+    def __new__(cls, *args: Any) -> now_:
+        result = cast(now_, object.__new__(cls, *args))
+
+        return result
+
+    def __str__(self) -> str_:
+        return datetime_.utcnow().isoformat(timespec="microseconds") + "Z"
+
+    def __repr__(self) -> str_:
+        return datetime_.utcnow().isoformat(timespec="microseconds") + "Z"
+
+
 class utcnow_(_baseclass):
+    now = now_()
+
     def __new__(cls, *args: Any) -> utcnow_:
         result = cast(utcnow_, object.__new__(cls, *args))
 
@@ -146,23 +170,60 @@ class utcnow_(_baseclass):
             return datetime_.utcnow().isoformat(timespec="microseconds") + "Z"
         return _transform_value(value)
 
+    def as_datetime(self, value: Union[str_, datetime_, object, int, float, Decimal, Real] = _SENTINEL) -> datetime_:
+        if value is _SENTINEL:
+            # 'datetime.datetime.now(UTC)' is faster than 'datetime.datetime.utcnow().replace(tzinfo=UTC)'
+            return datetime_.now(UTC)
+        return _timestamp_to_datetime(value)
+
+    def as_unixtime(self, value: Union[str_, datetime_, object, int, float, Decimal, Real] = _SENTINEL) -> float:
+        if value is _SENTINEL:
+            return time_.time()
+        return _timestamp_to_unixtime(value)
+
+    def timediff(
+        self,
+        begin: Union[str_, datetime_, object, int, float, Decimal, Real],
+        end: Union[str_, datetime_, object, int, float, Decimal, Real],
+        unit: str_ = "seconds",
+    ) -> float:
+        delta = _timestamp_to_datetime(end) - _timestamp_to_datetime(begin)
+        unit = unit.lower()
+
+        if unit in ("seconds", "second", "sec", "s"):
+            return delta.total_seconds()
+        if unit in ("minutes", "minute", "min", "m"):
+            return delta.total_seconds() / 60
+        if unit in ("hours", "hour", "h"):
+            return delta.total_seconds() / 3600
+        if unit in ("days", "day", "d"):
+            return delta.total_seconds() / 86400
+        if unit in ("weeks", "week", "w"):
+            return delta.total_seconds() / (86400 * 7)
+
+        raise ValueError(f"Unknown unit '{unit}' for utcnow.timediff")
+
     as_str = as_string
-    as_timestamp = as_string
+    as_rfc3339 = as_string
     to_string = as_string
     to_str = as_string
-    to_timestamp = as_string
+    to_rfc3339 = as_string
     get_string = as_string
     get_str = as_string
-    get_timestamp = as_string
+    get_rfc3339 = as_string
     get = as_string
     string = as_string
     str = as_string
-
-    def as_datetime(self, value: Union[str_, datetime_, object, int, float, Decimal, Real] = _SENTINEL) -> datetime_:
-        if value is _SENTINEL:
-            # return datetime_.utcnow().replace(tzinfo=UTC)
-            return datetime_.now(UTC)
-        return _timestamp_to_datetime(_transform_value(value))
+    rfc3339 = as_string
+    timestamp_rfc3339 = as_string
+    ts_rfc3339 = as_string
+    rfc3339_timestamp = as_string
+    rfc3339_ts = as_string
+    utcnow_rfc3339 = as_string
+    rfc3339_utcnow = as_string
+    now_rfc3339 = as_string
+    rfc3339_now = as_string
+    get_now = as_string
 
     as_date = as_datetime
     as_dt = as_datetime
@@ -176,6 +237,38 @@ class utcnow_(_baseclass):
     date = as_datetime
     dt = as_datetime
 
+    as_unix = as_unixtime
+    as_time = as_unixtime
+    as_timestamp = as_unixtime
+    as_ut = as_unixtime
+    as_ts = as_unixtime
+    as_float = as_unixtime
+    to_unixtime = as_unixtime
+    to_unix = as_unixtime
+    to_time = as_unixtime
+    to_timestamp = as_unixtime
+    to_ut = as_unixtime
+    to_ts = as_unixtime
+    to_float = as_unixtime
+    get_unixtime = as_unixtime
+    get_unix = as_unixtime
+    get_time = as_unixtime
+    get_timestamp = as_unixtime
+    get_ut = as_unixtime
+    get_ts = as_unixtime
+    get_float = as_unixtime
+    unixtime = as_unixtime
+    unix = as_unixtime
+    time = as_unixtime
+    timestamp = as_unixtime
+    ut = as_unixtime
+    ts = as_unixtime
+
+    time_diff = timediff
+    diff = timediff
+    timedelta = timediff
+    delta = timediff
+
     def __str__(self) -> str_:
         return self.as_string()
 
@@ -190,30 +283,41 @@ class _module(utcnow_):
     __email__: str_ = __email__
 
     utcnow = utcnow_()
-    now = utcnow_()
 
     def __new__(cls, *args: Any) -> _module:
         result = cast(_module, object.__new__(cls, *args))
 
+        setattr(result, "now", result.utcnow)
+
         return result
 
 
 _module_value = _module()
 utcnow = _module_value.utcnow
-now = _module_value.now
+now = utcnow
 
 as_string = _module_value.as_string
 as_str = as_string
-as_timestamp = as_string
+as_rfc3339 = as_string
 to_string = as_string
 to_str = as_string
-to_timestamp = as_string
+to_rfc3339 = as_string
 get_string = as_string
 get_str = as_string
-get_timestamp = as_string
+get_rfc3339 = as_string
 get = as_string
 string = as_string
 str = as_string
+rfc3339 = as_string
+timestamp_rfc3339 = as_string
+ts_rfc3339 = as_string
+rfc3339_timestamp = as_string
+rfc3339_ts = as_string
+utcnow_rfc3339 = as_string
+rfc3339_utcnow = as_string
+now_rfc3339 = as_string
+rfc3339_now = as_string
+get_now = as_string
 
 as_datetime = _module_value.as_datetime
 as_date = as_datetime
@@ -228,6 +332,41 @@ datetime = as_datetime
 date = as_datetime
 dt = as_datetime
 
+as_unixtime = _module_value.as_unixtime
+as_unix = as_unixtime
+as_time = as_unixtime
+as_timestamp = as_unixtime
+as_ut = as_unixtime
+as_ts = as_unixtime
+as_float = as_unixtime
+to_unixtime = as_unixtime
+to_unix = as_unixtime
+to_time = as_unixtime
+to_timestamp = as_unixtime
+to_ut = as_unixtime
+to_ts = as_unixtime
+to_float = as_unixtime
+get_unixtime = as_unixtime
+get_unix = as_unixtime
+get_time = as_unixtime
+get_timestamp = as_unixtime
+get_ut = as_unixtime
+get_ts = as_unixtime
+get_float = as_unixtime
+unixtime = as_unixtime
+unix = as_unixtime
+time = as_unixtime
+timestamp = as_unixtime
+ut = as_unixtime
+ts = as_unixtime
+
+timediff = _module_value.timediff
+time_diff = timediff
+diff = timediff
+timedelta = timediff
+delta = timediff
+
+
 __all__ = [
     "__version__",
     "__version_info__",
@@ -237,23 +376,70 @@ __all__ = [
     "now",
     "as_string",
     "as_str",
-    "as_timestamp",
+    "as_rfc3339",
     "to_string",
     "to_str",
-    "to_timestamp",
+    "to_rfc3339",
     "get_string",
     "get_str",
-    "get_timestamp",
+    "get_rfc3339",
+    "get",
     "string",
     "str",
+    "rfc3339",
+    "timestamp_rfc3339",
+    "ts_rfc3339",
+    "rfc3339_timestamp",
+    "rfc3339_ts",
+    "utcnow_rfc3339",
+    "rfc3339_utcnow",
+    "now_rfc3339",
+    "rfc3339_now",
+    "get_now",
     "as_datetime",
     "as_date",
+    "as_dt",
     "to_datetime",
     "to_date",
+    "to_dt",
     "get_datetime",
     "get_date",
+    "get_dt",
     "datetime",
     "date",
+    "dt",
+    "as_unixtime",
+    "as_unix",
+    "as_time",
+    "as_timestamp",
+    "as_ut",
+    "as_ts",
+    "as_float",
+    "to_unixtime",
+    "to_unix",
+    "to_time",
+    "to_timestamp",
+    "to_ut",
+    "to_ts",
+    "to_float",
+    "get_unixtime",
+    "get_unix",
+    "get_time",
+    "get_timestamp",
+    "get_ut",
+    "get_ts",
+    "get_float",
+    "unixtime",
+    "unix",
+    "time",
+    "timestamp",
+    "ut",
+    "ts",
+    "timediff",
+    "time_diff",
+    "diff",
+    "timedelta",
+    "delta",
 ]
 
 _actual_module = sys.modules[__name__]  # noqa
